======================
Django Hotsauce v0.4.5
======================

:Author: Etienne Robillard <erob@gthcfoundation.org>
:Version: 0.4.5
:Last modified: 2012-03-15

Welcome to the notmm toolkit developer's handbook! This is a work-in-progress
document and may contains errors and/or incompleted chapters, etc. You're
invited to send feedback or suggestions to erob@gthcfoundation.org about this
document.

Thanks for reading!

.. toctree::

    :maxdepth: 3

    handbook/getting-started
    handbook/customizing/advanced-configuration
    handbook/customizing/patching-django
    handbook/cheatsheet
    handbook/templates/mako


    reference/controllers/index
    reference/datastore
    reference/authentication
    reference/dbapi
    reference/urlmap

